# req_market_data_type { #shinybroker.req_market_data_type }

```python
req_market_data_type(marketDataType)
```

Create a string for setting your session's market data type

## Parameters {.doc-section .doc-section-parameters}

| Name           | Type         | Description                                                                                                                                         | Default    |
|----------------|--------------|-----------------------------------------------------------------------------------------------------------------------------------------------------|------------|
| marketDataType | [int](`int`) | Integer identifier for the [market data type]( https://www.interactivebrokers.com/campus/ibkr-api-page/twsapi-doc/#md-type-behavior ) that you want | _required_ |

## Examples {.doc-section .doc-section-examples}

```
import shinybroker as sb
# create a request string for setting the market data type to "DELAYED"
req_market_data_type_msg = sb.req_market_data_type(3)
print(req_market_data_type_msg)
```